==> owncloud-8.1.0p2.tgz: owncloud/apps/activity/l10n/de_DE.js <==
OC.L10N.register(
    "activity",
    {
    "Activity" : "Aktivität",
    "Personal activity feed for %s" : "Persönlicher Feed der Aktivitäten für %s",
    "Your feed URL is invalid" : "Ihre Feed-URL ist ungültig",
    "Your settings have been updated." : "Ihre Einstellungen wurden aktualisiert.",
    "This stream will show events like additions, changes & shares" : "Dieser Stream zeigt Ereignisse wie Hinzugekommenes, Änderungen und Freigaben an",
    "There are no events for this filter" : "Keine Ereignisse für diesen Filter vorhanden",
    "Activity notification" : "Benachrichtigung über die Aktivitäten",
    "All Activities" : "Alle Aktivitäten",
    "Activities by you" : "Ihre Aktivitäten",
    "Activities by others" : "Aktivitäten von Anderen",
    "\"remote user\"" : "„Entfernter Benutzer“",
    "in %s" : "unter %s",
    "%s and %s" : "%s und %s",
    ", " : ", ",
    "_%s and <strong class=\"tooltip\" title=\"%s\">%n more</strong>_::_%s and <strong class=\"tooltip\" title=\"%s\">%n more</strong>_" : ["%s und <strong class=\"tooltip\" title=\"%s\">%n mehr</strong>","%s und <strong class=\"tooltip\" title=\"%s\">%n mehrere</strong>"],
    "_%s and %n more_::_%s and %n more_" : ["%s und %n weiteres","%s und %n weitere"],
    "Hello %s," : "Hallo %s,",
    "You are receiving this email because in the last hour the following things happened at %s" : "Sie erhalten diese E-Mail, da in der letzten Stunde folgende Dinge bei %s geschehen sind",
    "You are receiving this email because in the last day the following things happened at %s" : "Sie erhalten diese E-Mail, da gestern folgende Dinge bei %s geschehen sind",
    "You are receiving this email because in the last week the following things happened at %s" : "Sie erhalten diese E-Mail, da in der letzten Woche folgende Dinge bei %s geschehen sind",
    "* %1$s - %2$s" : "* %1$s - %2$s",
    "_* and %n more _::_* and %n more _" : ["* und %n weiterer","* und %n weitere"],
    "Notifications" : "Benachrichtigungen",
    "Mail" : "Mail",
    "Stream" : "Stream",
    "List your own actions in the stream" : "Ihre eigenen Aktivitäten im Stream auflisten",
    "Notify about your own actions via email" : "Über Ihre eigenen Aktivitäten via E-Mail benachrichtigen",
    "You need to set up your email address before you can receive notification emails." : "Bevor Sie E-Mail-Benachrichtigungen empfangen können, müssen Sie Ihre E-Mail-Adresse einrichten.",
    "Send emails:" : "E-Mails senden:",
    "Hourly" : "stündlich",
    "Daily" : "täglich",
    "Weekly" : "wöchentlich",
    "Activity feed" : "Feed der Aktivitäten",
    "Enable RSS feed" : "RSS-Feed aktivieren",
    "No activity yet" : "Bislang keine Aktivitäten",
    "No more events to load" : "Keine weiteren Ereignisse zu Laden",
    "Files" : "Dateien"
},
"nplurals=2; plural=(n != 1);");

==> owncloud-8.2.2p3.tgz: owncloud/apps/activity/l10n/de_DE.js <==
OC.L10N.register(
    "activity",
    {
    "Activity" : "Aktivität",
    "Personal activity feed for %s" : "Persönlicher Feed der Aktivitäten für %s",
    "Your feed URL is invalid" : "Ihre Feed-URL ist ungültig",
    "Your settings have been updated." : "Ihre Einstellungen wurden aktualisiert.",
    "Mail" : "Mail",
    "Stream" : "Stream",
    "Activities" : "Aktivitäten",
    "Error loading activities" : "Fehler beim Laden von Aktivitäten.",
    "No activities" : "Keine Aktivitäten.",
    "This stream will show events like additions, changes & shares" : "Dieser Stream zeigt Ereignisse wie Hinzugekommenes, Änderungen und Freigaben an",
    "There are no events for this filter" : "Keine Ereignisse für diesen Filter vorhanden",
    "Activity notification" : "Benachrichtigung über die Aktivitäten",
    "All Activities" : "Alle Aktivitäten",
    "Activities by you" : "Ihre Aktivitäten",
    "Activities by others" : "Aktivitäten von Anderen",
    "\"remote user\"" : "„Entfernter Benutzer“",
    "in %s" : "unter %s",
    "%s and %s" : "%s und %s",
    ", " : ", ",
    "_%s and <strong %s>%n more</strong>_::_%s and <strong %s>%n more</strong>_" : ["%s und <strong %s>%n weitere</strong>","%s und <strong %s>%n weitere</strong>"],
    "_%s and %n more_::_%s and %n more_" : ["%s und %n weiteres","%s und %n weitere"],
    "Hello %s," : "Hallo %s,",
    "You are receiving this email because the following things happened at %s" : "Sie erhalten diese E-Mail, da folgende Dinge auf %s geschehen sind",
    "* %1$s - %2$s" : "* %1$s - %2$s",
    "_* and %n more _::_* and %n more _" : ["* und %n weiterer","* und %n weitere"],
    "Notifications" : "Benachrichtigungen",
    "List your own actions in the stream" : "Ihre eigenen Aktivitäten im Stream auflisten",
    "Notify about your own actions via email" : "Über Ihre eigenen Aktivitäten via E-Mail benachrichtigen",
    "You need to set up your email address before you can receive notification emails." : "Bevor Sie E-Mail-Benachrichtigungen empfangen können, müssen Sie Ihre E-Mail-Adresse einrichten.",
    "Send emails:" : "E-Mails senden:",
    "Hourly" : "stündlich",
    "Daily" : "täglich",
    "Weekly" : "wöchentlich",
    "Activity feed" : "Feed der Aktivitäten",
    "Enable RSS feed" : "RSS-Feed aktivieren",
    "No activity yet" : "Bislang keine Aktivitäten",
    "No more events to load" : "Keine weiteren Ereignisse zu Laden",
    "Files" : "Dateien",
    "_%s and <strong class=\"has-tooltip\" title=\"%s\">%n more</strong>_::_%s and <strong class=\"has-tooltip\" title=\"%s\">%n more</strong>_" : ["%s und <strong class=\"has-tooltip\" title=\"%s\">%n weitere</strong>","%s und <strong class=\"has-tooltip\" title=\"%s\">%n weitere</strong>"]
},
"nplurals=2; plural=(n != 1);");
